@@ -31,12 +31,12 @@ def around(a, decimals=0, out=None):
             a float.
 
     Examples:
-        >>> x = numpoly.symbols("x")
-        >>> numpoly.around([0.37, 1.64*x-2.45])
-        polynomial([0.0, 2.0*x-2.0])
-        >>> numpoly.around([0.37, 1.64*x-23.45], decimals=1)
-        polynomial([0.4, 1.6*x-23.4])
-        >>> numpoly.around([0.37, 1.64*x-23.45], decimals=-1)
+        >>> q0 = numpoly.variable()
+        >>> numpoly.around([0.37, 1.64*q0-2.45])
+        polynomial([0.0, 2.0*q0-2.0])
+        >>> numpoly.around([0.37, 1.64*q0-23.45], decimals=1)
+        polynomial([0.4, 1.6*q0-23.4])
+        >>> numpoly.around([0.37, 1.64*q0-23.45], decimals=-1)
         polynomial([0.0, -20.0])
 
     """
